@@ -1,4 +1,3 @@
 from simple_ddl_parser.ddl_parser import DDLParser, parse_from_file
 
-
-__all__ = ['DDLParser', 'parse_from_file']
+__all__ = ["DDLParser", "parse_from_file"]
